"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHub = void 0;
var signalr_1 = require("@microsoft/signalr");
var react_1 = require("react");
/**
 * Start/Stop the provided hub connection (on connection change or when the component is unmounted)
 * @param {HubConnection} hubConnection The signalR hub connection
 * @return {HubConnection} the current signalr connection
 * @return {any} the signalR error in case the start does not work
 */
function useHub(hubConnection) {
    var _a;
    var _b = react_1.useState((_a = hubConnection === null || hubConnection === void 0 ? void 0 : hubConnection.state) !== null && _a !== void 0 ? _a : signalr_1.HubConnectionState.Disconnected), hubConnectionState = _b[0], setHubConnectionState = _b[1];
    var _c = react_1.useState(), error = _c[0], setError = _c[1];
    react_1.useEffect(function () {
        setError(undefined);
        if (!hubConnection) {
            setHubConnectionState(signalr_1.HubConnectionState.Disconnected);
            return;
        }
        if (hubConnection.state !== hubConnectionState) {
            setHubConnectionState(hubConnection.state);
        }
        var isMounted = true;
        var onStateUpdatedCallback = function () {
            if (isMounted) {
                setHubConnectionState(hubConnection === null || hubConnection === void 0 ? void 0 : hubConnection.state);
            }
        };
        hubConnection.onclose(onStateUpdatedCallback);
        hubConnection.onreconnected(onStateUpdatedCallback);
        hubConnection.onreconnecting(onStateUpdatedCallback);
        if (hubConnection.state === signalr_1.HubConnectionState.Disconnected) {
            var startPromise_1 = hubConnection
                .start()
                .then(onStateUpdatedCallback)
                .catch(function (reason) { return setError(reason); });
            onStateUpdatedCallback();
            return function () {
                startPromise_1.then(function () {
                    hubConnection.stop();
                });
                isMounted = false;
            };
        }
        return function () {
            hubConnection.stop();
        };
    }, [hubConnection]);
    return { hubConnectionState: hubConnectionState, error: error };
}
exports.useHub = useHub;
