"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHubReceiver = void 0;
var react_1 = require("react");
/**
 * Registers a handler that will be invoked when the hub method with the specified method name is invoked.
 * @param {HubConnection} hubConnection The signalR hub connection.
 * @param {string} methodName The name of the hub method to define.
 * @param {Function} method The handler that will be raised when the hub method is invoked.
 */
function useHubReceiver(hubConnection, methodName, method) {
    react_1.useEffect(function () {
        if (!hubConnection) {
            return;
        }
        hubConnection.on(methodName, method);
        return function () {
            hubConnection.off(methodName, method);
        };
    }, [hubConnection, method, methodName]);
}
exports.useHubReceiver = useHubReceiver;
